// {{{ copyright

/********************************************************************
 *
 * $Id: Command.java,v 1.6 2000/11/14 12:49:22 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.command;

import java.util.EventObject;

/**
 * Commands are similar to the events of a GUI, but operate at a higher level
 * of abstraction. They can be created anywhere and passed to a
 * {@link CommandDistributor CommandDistributor} that will either execute
 * them directly or pass them on to suitable
 * {@link CommandHandler CommandHandlers}.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.6 $
 */
public class Command extends EventObject
{
    // {{{ variables

    /**
     * The handled state of the Command.
     */
    private boolean handled;

    // }}}

    // {{{ constructor

    /**
     * Create a new Command object.
     *
     * @param   source  The source from which the Command originated.
     */
    public Command (Object source)
    {
        super (source);
    }

    // }}}

    // {{{ isHandled

    /**
     * Query whether the Command was already handled.
     *
     * @return  The handled state of the Command.
     */
    public final boolean isHandled()
    {
        return handled;
    }

    // }}}
    // {{{ setHandled

    /**
     * Set the handled state of the Command.
     *
     * @param   handled The handled state to set.
     */
    public final void setHandled(boolean handled)
    {
        this.handled = handled;
    }

    // }}}
    // {{{ mustBeHandled

    /**
     * Test whether the Command must be handled. If true, the {@link
     * CommandDistributor CommandDistributor} will throw an {@link
     * UnhandledCommandException UnhandledCommandException} in {@link
     * CommandDistributor#assignCommandSilently assignCommandSilently} if it
     * cannot find a handler for the command. <p>
     *
     * The default is to always return true, but you can override this method
     * in a derived class to signal otherwise, which is useful for message type
     * commands with possibly multiple receivers.
     *
     * @return  True.
     * @since   0.98.0
     */
    public boolean mustBeHandled()
    {
        return true;
    }

    // }}}
}
