// {{{ copyright

/********************************************************************
 *
 * $Id: JFrameConfigWrapper.java,v 1.7 2000/06/06 17:00:02 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.config;

// {{{ imports

import java.awt.Dimension;
import java.awt.Point;

import javax.swing.JFrame;

import java.io.Serializable;

import de.qfs.lib.gui.SwingUtil;

// }}}

/**
 * A ConfigWrapper for {@link javax.swing.JFrame JFrame} objects.
 * The only difference from FrameConfigWrapper is that the setState method
 * transfers the action to the awt event loop since swing components aren't
 * thread safe.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.7 $
 */
public class JFrameConfigWrapper
extends FrameConfigWrapper
{
    // {{{ constructor

    /**
     * Create a new JFrameConfigWrapper with the default name "frame".
     */
    public JFrameConfigWrapper()
    {
        setConfigurableName("frame");
    }

    // }}}

    // {{{ restore

    /**
     * Restore the frame's size and location.
     *
     * @param   size            The size to set.
     * @param   location        The location to set.
     */
    protected void restore (final Dimension size, final Point location)
    {
        final JFrame frame = (JFrame)this.frame;

        SwingUtil.invokeAndWait(new Runnable() {
            public void run() {
                frame.setLocation (location);
                frame.pack();
                frame.setSize(size);
                frame.validate();
            }
        });
    }

    // }}}
}
