// {{{ copyright

/********************************************************************
 *
 * $Id: LogClient.java,v 1.1 2000/07/04 13:43:50 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.logrmi;

// {{{ imports

import java.rmi.Remote;
import java.rmi.RemoteException;

// }}}

/**
 * This interface must be implemented by LogServer clients that wish to
 * register themselves in the RMI registry and connected to a LogServer once
 * it starts up.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.1 $
 */
public interface LogClient
    extends Remote
{
    /**
     * LogClients should register themselves under a name that starts with
     * this string.
     */
    public final static String REGISTRY_BASE_NAME = "LogClient-";

    /**
     * Tell the LogClient that it should disengage from the registry and
     * connect itself to a LogServer.
     *
     * @param   server  The LogServer to connect to.
     *
     * @throws  RemoteException If something RMI specific goes wrong.
     */
    public void connect(LogServer server)
        throws RemoteException;
}
