// {{{ copyright

/********************************************************************
 *
 * $Id: ChoiceOption.java,v 1.3 2000/12/12 17:26:01 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 2000 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.option;

// {{{ imports

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * A ChoiceOption is an Option that is edited with the help of a {@link
 * ChoiceOptionEdit ChoiceOptionEdit}.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.3 $
 */
public class ChoiceOption
    extends Option
    implements ConfigurableOption
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger = new Logger (ChoiceOption.class);

    // }}}
    // {{{ constructors

    /**
     * Create a new ChoiceOption.
     */
    public ChoiceOption ()
    {
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "ChoiceOption()", "");
        }
    }

    /**
     * Create a new ChoiceOption.
     *
     * @param   name    The name of the ChoiceOption.
     * @param   value   The initial value.
     */
    public ChoiceOption(String name, Object value)
    {
        super(name, value);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "ChoiceOption(String,Object)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "name: " + name + ", " +
                       "value: " + value);
        }
    }

    // }}}

    //----------------------------------------------------------------------
    // The ConfigurableOption interface
    //----------------------------------------------------------------------
    // {{{ getConfigurableValue

    /**
     * Get the Option's value as a String.
     *
     * @return  The Option's value as a String.
     */
    public String getConfigurableValue()
    {
        Object value = getValue();
        return value == null ? "" : value.toString();
    }

    // }}}
    // {{{ setConfigurableValue

    /**
     * Set the Option's value from a String.
     *
     * @param   val     The value to set.
     */
    public void setConfigurableValue(String val)
    {
        setValue(val.equals("") ? null : val);
    }

    // }}}
}
