// {{{ copyright

/********************************************************************
 *
 * $Id: ConfigurableOption.java,v 1.6 2000/06/06 16:41:27 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.option;

/**
 * Options that implement this interface will be saved and restored via the
 * {@link de.qfs.lib.config.Configuration Configuration} mechanism, when they
 * are contained in an {@link OptionSet OptionSet} that is registered with the
 * Configuration.  Implementing ConfigurableOption guarantees that the
 * Option's value can be converted into and read back from a String, where the
 * empty String represents the null value, since null values are not allowed
 * in a {@link java.util.Properties Properties} object.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.6 $
 */
public interface ConfigurableOption
{
    /**
     * Get the Option's value as a String. A null value will be converted
     * into the empty String for storage in a Properties object.
     *
     * @return  The Option's value as a String.
     */
    public String getConfigurableValue();

    /**
     * Set the Option's value from a String.
     *
     * @param   value   The value to set. Guaranteed to be non-null.
     */
    public void setConfigurableValue(String value);
}
