// {{{ copyright

/********************************************************************
 *
 * $Id: Commitable.java,v 1.4 2000/06/14 16:51:57 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.transaction;

/**
 * A Commitable serves as a placeholder for an action that is either delayed
 * until it is safe to execute, or that can be undone. <p>
 *
 * Commitables are collected in a {@link Transaction Transaction} and either
 * will all of them be {@link #commit commited} or all of them {@link
 * #rollback rolled back}. If something really bad happens during commit or
 * rollback, e.g. a database commit fails, a FatalTransactionException should
 * be thrown to signal that the whole commit or rollback operation is void.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.4 $
 * @since       0.97.0
 */
public interface Commitable
{
    /**
     * Commit the action of the Commitable.
     *
     * @throws  FatalTransactionException       If something fails in a way
     *          that makes completion of commit impossible.
     */
    public void commit()
         throws FatalTransactionException;

    /**
     * Undo the action of the Commitable.
     *
     * @throws  FatalTransactionException       If something fails in a way
     *          that makes completion of rollback impossible.
     */
    public void rollback()
         throws FatalTransactionException;
}
