// {{{ copyright

/********************************************************************
 *
 * $Id: StateHolder.java,v 1.4 2000/06/14 16:52:02 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.transaction;

/**
 * The StateHolder interface is used by {@link CommitableStateChange
 * CommitableStateChange} to make the change of an Object's state
 * part of a {@link Transaction Transaction}. <p>
 *
 * The StateHolder's {@link #saveState saveState} method is called by
 * the constructor of the CommitableStateChange. Its return value can
 * hold any kind of information that will be passed on to {@link
 * #commitState commitState} or {@link #restoreState restoreState},
 * e.g. the saved state itself or just a flag, whether the
 * state was actually saved.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.4 $
 * @since       0.97.0
 */
public interface StateHolder
{
    /**
     * Save the StateHolder's state.
     *
     * @return  Some information that is useful during {@link #commitState
     *          commitState} or {@link #restoreState restoreState}.
     */
    public Object saveState();

    /**
     * Commit the saved state of the StateHolder. Typically a noop.
     *
     * @param   info    The information returned from {@link #saveState
     *                  saveState}.
     *
     * @throws FatalTransactionException If something fails in a way that
     *          corrupts the whole Transaction.
     */
    public void commitState(Object info)
         throws FatalTransactionException;

    /**
     * Restore the StateHolder's state.
     *
     * @param   info   The information returned from {@link #saveState
     *                  saveState}.
     *
     * @throws FatalTransactionException If something fails in a way that
     *          corrupts the whole Transaction.
     */
    public void restoreState(Object info)
         throws FatalTransactionException;
}
