// {{{ copyright

/********************************************************************
 *
 * $Id: NodeFactory.java,v 1.1 2001/04/06 15:03:22 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 2000 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.tree;

/**
 * This interface must be implement in order to create a tree with a {@link
 * TreeBuilder TreeBuilder}.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.1 $
 * @since       0.98.1
 */
public interface NodeFactory
{
    /**
     * Create a new tree node. Called when a node is encountered for the first
     * time.
     *
     * @param   data    Some information about the node.
     *
     * @return The new node. It is ok to return null if no node should be
     *         created for the data.
     */
    public Object createNode(Object data);

    /**
     * Finish a tree node. Called when all of the node's children have been
     * built and finished.
     *
     * @param   node    The node to finish.
     */
    public void finishNode(Object node);
}
