// {{{ copyright

/********************************************************************
 *
 * $Id: Traversal.java,v 1.2 2001/04/06 15:03:52 gs Exp $
 *
 * Copyright (C) 2000 Gregor Schmid, Quality First Software
 * All rights reserved
 *
 *******************************************************************/

// }}}

package de.qfs.lib.tree;

// {{{ imports

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * This interface is implemented by classes that traverse a tree.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.2 $
 * @since       0.98.1
 */
public interface Traversal
{
    // {{{ getAdapter

    /**
     * Get the TreeAdapter of the tree being traversed.
     *
     * @return  The TreeAdapter of the tree being traversed.
     */
    public TreeAdapter getAdapter();

    // }}}
    // {{{ getNode

    /**
     * Get the current node of the traversal.
     *
     * @return  The current node of the traversal.
     */
    public Object getNode();

    // }}}
    // {{{ getParent

    /**
     * Get the parent node of the traversal.
     *
     * @return  The parent node of the traversal.
     */
    public Object getParent();

    // }}}
    // {{{ getIndex

    /**
     * Get the index of the current node in its parent. Depending on the type
     * of the adapter this method may perform better than {@link
     * TreeAdapter#getIndexOfChildNode TreeAdapter.getIndexOfChildNode}.
     *
     * @return  The index of the node in its parent.
     */
    public int getIndex();

    // }}}
    // {{{ getPath

    /**
     * Get the path of the current node realtive to the node the traversal was
     * started at.
     *
     * @return  The path of the current node.
     */
    public Object[] getPath();

    // }}}
    // {{{ getPreviousSibling

    /**
     * Get the previous sibling of the current node.
     *
     * @return  The previous sibling of the current node.
     */
    public Object getPreviousSibling();

    // }}}
    // {{{ finish

    /**
     * Cleanly abort the traversal.
     */
    public void finish();

    // }}}
    // {{{ getUserObject

    /**
     * Get a user object associated with this traversal. Useful for
     * communication between different nodes during traversal.
     *
     * @return  The user object associated with this traversal.
     */
    public Object getUserObject();

    // }}}
    // {{{ setUserObject

    /**
     * Set a user object associated with this traversal. Useful for
     * communication between different nodes during traversal.
     *
     * @param   object  The user object to set.
     */
    public void setUserObject(Object object);

    // }}}
}
