// {{{ copyright

/********************************************************************
 *
 * $Id: MRUCacheEvent.java,v 1.1 2000/09/06 07:15:13 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 2000 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.util;

// {{{ imports

import java.util.EventObject;

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * Event object that contains details about resources being dropped from an
 * overflowing {@link MRUCache MRUCache}.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.1 $
 * @since       0.98.0
 */
public class MRUCacheEvent
    extends EventObject
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger = new Logger (MRUCacheEvent.class);

    /**
     * The key the resource was stored under.
     */
    private Object key;

    /**
     * The resource that is removed from the MRUCache.
     */
    private Object resource;

    // }}}

    // {{{ constructor

    /**
     * Create a new MRUCacheEvent.
     *
     * @param   source  The source of the event, typically the {@link
     *          MRUCache MRUCache}.
     * @param   key     The key the resource was stored under.
     * @param   resource The resource that is removed from the MRUCache.
     */
    public MRUCacheEvent (Object source, Object key, Object resource)
    {
        super(source);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "CountEvent(Object,Object,Object)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "source: " + source + ", " +
                       "key: " + key + ", " +
                       "resource: " + resource);
        }
        this.key = key;
        this.resource = resource;
    }

    // }}}

    // {{{ getKey

    /**
     * Get the key the resource was stored under.
     *
     * @return  The key the resource was stored under.
     */
    public Object getKey()
    {
        return key;
    }

    // }}}
    // {{{ getResource

    /**
     * Get the resource that is removed from the MRUCache.
     *
     * @return  The resource that is removed from the MRUCache.
     */
    public Object getResource()
    {
        return resource;
    }

    // }}}

    // {{{ toString

    /**
     * Get a String representation for the event.
     *
     * @return  The String representation for the event.
     */
    public String toString()
    {
        return super.toString() +
            "[key=" + key +
            ",resource=" + resource + "]";
    }

    // }}}
}
